import os.path
from .support import subprocess_call, temporary_write, name_and_ext



def concat_videos(in_paths, out_path):
    in_paths = [os.path.abspath(path) for path in in_paths]
    name, _ = name_and_ext(out_path)
    file_list = '\n'.join(f'file {path}' for path in in_paths)
    with temporary_write(file_list, path=f'{name}_files.txt') as list_path:
        subprocess_call([
            'ffmpeg',
            '-f',
            'concat',
            '-y',
            '-safe',
            '0',
            '-i',
            list_path,
            '-c',
            'copy',
            out_path
        ])
    return out_path



from .support import name_and_ext, temporary_write, subprocess_call

def get_video_duration(input_path):
    cmd = f"ffprobe -v error -select_streams v:0 -show_entries stream=duration -of default=noprint_wrappers=1:nokey=1 {input_path}"
    data = subprocess_call([x.strip() for x in cmd.split(' ') if x.strip()])
    data = [x for x in data.split('\n') if x.strip()][0].strip()
    try:
        return float(data)
    except:
        return None

def get_audio_duration(input_path):
    cmd = f"ffprobe -v error -select_streams a:0 -show_entries stream=duration -of default=noprint_wrappers=1:nokey=1 {input_path}"
    data = subprocess_call([x.strip() for x in cmd.split(' ') if x.strip()])
    data = [x for x in data.split('\n') if x.strip()][0].strip()
    try:
        return float(data)
    except:
        return None

def extract_audio_subclip(filename, targetname, start, end, ):
    cmd = [
      "ffmpeg","-y",
      "-i", filename,
      "-ss", "%0.3f" % (start),
      "-map","0:a",
      "-c:a", "aac",
      targetname
    ]
    subprocess_call(cmd)
    return targetname

def merge_audio_video(audio_path, video_path, out_path):
    cmd = [
      "ffmpeg","-y",
      "-i", audio_path,
      "-i", video_path,
      # "-strict",
      # "-2",
      # "-vcodec", "copy", "-acodec", "copy",
      "-map","0:a",
      "-map","1:v",
      "-c", "copy",
      # "-crf", "18",
      out_path
    ]
    subprocess_call(cmd)
    return out_path

def align_audio_video(in_path, out_path):
    v_duration = get_video_duration(in_path)
    a_duration = get_audio_duration(in_path)
    if not v_duration or not a_duration:
        return
    # if a_duration >= v_duration:
    name, ext = name_and_ext(in_path)
    with temporary_write('', path=f'{name}_temp_audio{ext}') as path:
        start = a_duration - v_duration
        audio_path = extract_audio_subclip(in_path, path, start, a_duration)
        out_path = merge_audio_video(audio_path, in_path, out_path)
        return out_path




if __name__ == '__main__':
    dur = get_audio_duration('/Users/morse/Documents/GitHub/twitch-to-youtube/data/videos/panetty_2019-04-07/./video_subclips/video_5.m2ts')
    print(dur)



import os.path
import os
from .cut_video import cut_video
from .support import name_and_ext



# def merge_overlap(acc, timeframe):
#     # print('timeframe',timeframe)
#     # print('acc',acc)
#     accuracy = 4 # seconds
#     start2, end2 = timeframe
#     start1, end1 = acc[-1] if acc else timeframe
#     if start2 - end1 <= accuracy:
#         return  [*acc[:-1], (start1, end2),  ]
#     else:
#         return [*acc, timeframe, ]


def cut_timeframes(in_path, timeframes, out_dir='./', out_pattern='{name}_{i}{ext}', ):
    for (i, (start, end)) in enumerate(timeframes):
        try:
            name, ext = name_and_ext(in_path)
            out_path = os.path.join(out_dir, out_pattern.format(name=name, ext=ext, i=i))
            out_path = cut_video(in_path, out_path, start, end)
            # os.remove(out_path)
            yield out_path
        except Exception as e:
            print(f'got exception {e}')
            pass





from .support import name_and_ext, temporary_write, subprocess_call

def get_video_codec(input_path):
    cmd = f"ffprobe -v error -select_streams v:0 -show_entries stream=codec_name -of default=noprint_wrappers=1:nokey=1 {input_path}"
    data = subprocess_call([x.strip() for x in cmd.split(' ') if x.strip()])
    data = [x for x in data.split('\n') if x.strip()][0].strip()
    try:
        return data
    except:
        return None



from setuptools import setup



with open('VERSION', 'r') as fh:
    version = fh.read()

with open('requirements.txt', 'r') as fh:
    requirements = [x for x in fh.read().split('\n') if x]

setup(name='video_cut',
      version=version,
      description='Youtube video uploader',
      long_description="check https://github.com/remorses/video_cut for more",
      long_description_content_type='text/markdown',
      url='https://github.com/remorses/video_cut',
      author='Tommaso De Rossi',
      author_email='beats.by.morse@gmail.com',
      license='MIT',
      packages=['video_cut'],
      install_requires=requirements,
      zip_safe=False
)
